import os
import time

def typewriter(text, delay: float = 0.5):
    """
    Prints text like a typewriter, clearing the screen each step.

    Args:
        text (str): Text to display.
        delay (float): Delay between characters in seconds.
    """
    typed = ""
    for char in str(text):
        typed += char
        
        if os.name == "nt":
            os.system("cls")
        else:
            os.system("clear")

        print(typed)
        time.sleep(delay)



from setuptools import setup, find_packages

setup(
    name="pythontyperlol",  # Pypi name
    version="1.0.0",
    description="A python module i made i guess :D",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Arran Hewitt",
    packages=find_packages(),
    python_requires=">=3.7",
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License",
    ],
)
